@@ -12,6 +12,11 @@ trmatplot.depmix.fitted <- function(d, seed = NULL,
 													plot = TRUE,
                        		verbose = FALSE, ...) {
 
+	## ----------------------CHECK
+  ## probability transition matrix within depmix.fitted object
+	if (!class(d@transition[[1]]@parameters$coefficients)=="numeric") {
+		stop("[!] ensure that the depmix.fitted object contains a probability transition matrix")
+	}
 	## ----------------------PREPARE
 	d <- trmat.depmix.fitted(d)
  
